Learn R Programming

calibrationband (version 0.2.1)

print.calibrationband: Print monotone confidence bands

Description

Printing methods for 'calibrationband' and 'summary.calibrationband' objects.

Usage

# S3 method for calibrationband
print(x, ...)

# S3 method for summary.calibrationband print(x, ...)

Value

Invisibly returns x.

Arguments

x

object of class calibrationband

...

Further arguments to be passed to or from methods; in particular these passed to autoplot.calibrationband

Details

print.calibrationband always sends an autoplot object to the current graphics device and prints a summary to the console.

See Also

autoplot.calibrationband, summary.calibrationband