powered by
Printing methods for 'calibrationband' and 'summary.calibrationband' objects.
'calibrationband'
'summary.calibrationband'
# S3 method for calibrationband print(x, ...)# S3 method for summary.calibrationband print(x, ...)
# S3 method for summary.calibrationband print(x, ...)
Invisibly returns x.
x
object of class calibrationband
calibrationband
Further arguments to be passed to or from methods; in particular these passed to autoplot.calibrationband
autoplot.calibrationband
print.calibrationband always sends an autoplot object to the current graphics device and prints a summary to the console.
print.calibrationband
autoplot.calibrationband, summary.calibrationband
summary.calibrationband